//_____ I N C L U D E S
#include <stdio.h>
#include <math.h>
#include <SPI.h>
#include <Wire.h>
#include "MS5803_05.h"
#include "MS5803_05_SPI.h"


const int miso_port = 50; //SDI
const int mosi_port = 51; //SDO
const int sck_port = 52;  //SLCK
const int slaveSelectPin = 53; // CSB 

// Declare 'sensor' as the object that will refer to your MS5803 in the sketch
// Enter the oversampling value as an argument. Valid choices are
// 256, 512, 1024, 2048, 4096. Library default = 512 and Pin 53 for Arduino Mega
MS_5803 sensor = MS_5803(512);
MS_5803_SPI sensor_spi = MS_5803_SPI(4096, slaveSelectPin);


void setup() 
{
  pinMode(miso_port, INPUT);
  pinMode(mosi_port, OUTPUT);
  pinMode(slaveSelectPin, OUTPUT);
  pinMode(sck_port, OUTPUT);  
  
  Serial.begin(9600);
  //SPI BUS
  if (sensor_spi.initializeMS_5803_SPI()) {
    Serial.println( "MS5803 SPI CRC check OK." );
  } 
  else {
    Serial.println( "MS5803 SPI CRC check FAILED!" );
  }  
  
  //I2C BUS
  delay(1000);
  if (sensor.initializeMS_5803()) {
    Serial.println( "MS5803 I2C CRC check OK." );
  } 
  else {
    Serial.println( "MS5803 I2C CRC check FAILED!" );
  }  
  
}

void loop() 
{
  Serial.println("SPI Sensor first pressure [mbar], than temperature[°C]:");
  sensor_spi.readSensor();
  
  // Show pressure
  Serial.print("Pressure = ");
  Serial.print(sensor_spi.pressure()); 
  Serial.println(" mbar");
  
  // Show temperature
  Serial.print("Temperature = ");
  Serial.print(sensor_spi.temperature());
  Serial.println("C"); 

  ////********************************************************
  Serial.println("");
  
  Serial.println("I2C Sensor first pressure [mbar], than temperature[°C]:");
  sensor.readSensor();
  // Show pressure
  Serial.print("Pressure = ");
  Serial.print(sensor.pressure());
  Serial.println(" mbar");
  
  // Show temperature
  Serial.print("Temperature = ");
  Serial.print(sensor.temperature());
  Serial.println("C"); 
  
  delay(2000);
}
//********************************************************
//! @Check i2C Bus
//!
//! @return Address
//********************************************************
void checki2cbus()
{
  byte error, address; //variable for error and I2C address
  int nDevices;

  Serial.println("Scanning...");

  nDevices = 0;
  for (address = 1; address < 127; address++ )
  {
    // The i2c_scanner uses the return value of
    // the Write.endTransmisstion to see if
    // a device did acknowledge to the address.
    Wire.beginTransmission(address);
    error = Wire.endTransmission();

    if (error == 0)
    {
      Serial.print("I2C device found at address 0x");
      if (address < 16)
        Serial.print("0");
      Serial.print(address, HEX);
      Serial.println("  !");
      nDevices++;
    }
    else if (error == 4)
    {
      Serial.print("Unknown error at address 0x");
      if (address < 16)
        Serial.print("0");
      Serial.println(address, HEX);
    }
    else
    {
      //Serial.println(address, HEX);
    }
  }
  if (nDevices == 0)
    Serial.println("No I2C devices found\n");
  else
    Serial.println("done\n");

  delay(1000); // wait 
}
